#
# spec file for package fonts-config
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           fonts-config
Version:        20200609+git0.42e2b1b
Release:        150000.4.10.1
Summary:        Script to configure fonts for X Windows and other applications
# MIT for infinality
License:        GPL-2.0-or-later AND MIT
Group:          System/X11/Fonts
Source:         %{name}-%{version}.tar.xz
# bsc#1210700
Patch0:          fonts-config-homedir-getpwuid.patch
BuildRequires:  fontconfig
BuildRequires:  fontpackages-devel
Requires(pre):  %fillup_prereq
%reconfigure_fonts_prereq
Requires:       fontconfig
Requires:       gawk
Requires:       perl(English)
Recommends:     mkfontscale
Recommends:     mkfontdir
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
A script to configure fonts for X Windows and other applications.

fonts-config is usually called automatically when a package containing
fonts is installed, upgraded or removed. But it can also be executed
directly, which is mainly useful to debug it (use the --debug flag).

%prep
%setup
%patch0 -p1

%build
# empty configuration now, should be filled after fonts-config call
cp 99-example.conf 10-rendering-options.conf
# empty configuration now, can be filled after fonts-config call
cp 99-example.conf 58-family-prefer-local.conf

%install
mkdir -p %{buildroot}/sbin/conf.d
mkdir -p %{buildroot}%{_prefix}/sbin
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}/%{_mandir}/man1
mkdir -p %{buildroot}/%{_docdir}/%{name}/infinality
mkdir -p %{buildroot}%{_fillupdir}
install -m 755 fonts-config %{buildroot}%{_prefix}/sbin
install -m 644 sysconfig.fonts-config \
  %{buildroot}%{_fillupdir}/
install -m 644 fontconfig.SUSE.properties.template %{buildroot}%{_datadir}/fonts-config
pod2man --section 1 --center=" " fonts-config > \
  %{buildroot}/%{_mandir}/man1/fonts-config.1
#
install -m 644 10-rendering-options.conf.template %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_fontsconfavaildir}
# following two conf files can not be under /usr/share/fonts-config
# as they are changed during installation [bnc#882029 (internal)]
mkdir -p %{buildroot}%{_fontsconfddir}
for conf in     10-rendering-options.conf \
                58-family-prefer-local.conf; do
  install -m 644 $conf %{buildroot}%{_fontsconfddir}
done
#
for conf in 	10-group-tt-hinted-fonts.conf \
		10-group-tt-non-hinted-fonts.conf \
		11-base-rendering.conf \
		12-tt-monospace-rendering.conf \
		13-selective-rendering.conf \
		13-selective-rendering-ipa.conf \
    21-emoji-rendering.conf \
    31-metric-aliases-bw.conf \
    32-emoji-reject.conf \
    32-symbol-substitution.conf \
		49-family-default.conf \
		59-family-prefer-lang-specific.conf \
		60-family-prefer.conf \
		61-wine-aliases.conf \
		70-reject.conf; do
  install -m 644 $conf %{buildroot}%{_datadir}/%{name}/conf.avail/
  %link_avail_to_system_fontsconf $conf
done

%post
if [ -f %{_sysconfdir}/sysconfig/fonts-config ]; then
  update=$(grep "^FORCE_MODIFY_DEFAULT_FONT_SETTINGS_IN_NEXT_UPDATE=" %{_sysconfdir}/sysconfig/fonts-config | sed -e 's/.*="//;s/"$//')
  if [ -z "$update" -o "$update" = "yes" ]; then
     echo "Updating default font settings..."
     force_hintstyle=$(grep "^FORCE_HINTSTYLE=" /usr/share/fillup-templates/sysconfig.fonts-config | sed -e 's/.*=//')
     use_lcdfilter=$(grep "^USE_LCDFILTER=" /usr/share/fillup-templates/sysconfig.fonts-config | sed -e 's/.*=//')
     use_rgba=$(grep "^USE_RGBA=" /usr/share/fillup-templates/sysconfig.fonts-config | sed -e 's/.*=//')
     if [ ! -f %{_sysconfdir}/sysconfig/fonts-config.rpmsave ]; then
         cp %{_sysconfdir}/sysconfig/fonts-config %{_sysconfdir}/sysconfig/fonts-config.rpmsave
     fi
     sed -i -e '14,16s/^## Default:     none$/## Default:     '"$force_hintstyle"/ \
            -e 's/^FORCE_HINTSTYLE="none"$/FORCE_HINTSTYLE='"$force_hintstyle"/ \
            -e 's/^## Default:     lcdnone$/## Default:     '"$use_lcdfilter"/ \
            -e 's/^USE_LCDFILTER="lcdnone"$/USE_LCDFILTER='"$use_lcdfilter"/ \
            -e '76,78s/^## Default:     none$/## Default:     '"$use_rgba"/ \
            -e 's/^USE_RGBA="none"$/USE_RGBA='"$use_rgba"/ \
               %{_sysconfdir}/sysconfig/fonts-config
  fi
fi
# Note that the above code should run before fillup merges the (maybe new)
# FORCE_MODIFY_DEFAULT_FONT_SETTINGS_IN_NEXT_UPDATE variable
# in a system being updated.
%{fillup_only -n fonts-config}
%reconfigure_fonts_post -c
exit 0

%postun
%reconfigure_fonts_postun -c

%posttrans
%reconfigure_fonts_posttrans

%files
%defattr(-,root,root)
%dir %{_datadir}/fonts-config
%files_fontsconf_availdir
%{_sbindir}/fonts-config
%{_datadir}/fonts-config/*.template
%{_mandir}/man1/fonts-config.1.gz
%{_docdir}/%{name}
%{_fillupdir}/sysconfig.fonts-config
%{_fontsconfavaildir}/*.conf
%config %{_fontsconfddir}/*.conf

%changelog
* Thu Jun  1 2023 pgajdos@suse.com
- get the homedir from getpwuid when no $ENV{"HOME"} set
- added patches
  fix bsc#1210700
  + fonts-config-homedir-getpwuid.patch
* Tue Jun  9 2020 alarrosa@suse.com
- Add a _service file
- Add code in %%post to check the value of
  FORCE_MODIFY_DEFAULT_FONT_SETTINGS_IN_NEXT_UPDATE and if it's
  set to yes, empty or it doesn't exist, then update the values
  of FORCE_HINTSTYLE, USE_LCDFILTER and USE_RGBA in
  /etc/sysconfig/fonts-config to use the default settings
  established in the 20181211 release (boo#1172022)
- Update to 20200609+git0.42e2b1b:
  * Add variable to allow fonts-config to update default settings
  * Fix en-US, en-GB font matching
* Sat Jan 19 2019 qantas94heavy@gmail.com
- Update to 20190119
  * Allow non-ASCII letters in font names (boo#1049056, bnc#1101985).
* Tue Dec 11 2018 sflees@suse.de
- Update to 20181211
  * Update subpixel rendering config
  * Fix missspelling issue (boo#1111791). so
    Drop fonts-config-fix-misspelling.patch
  * Fix (boo#1092737).
  * other minor tidyups
* Mon Nov  5 2018 jengelh@inai.de
- Use noun phrasing and user-independent wording.
* Mon Oct 15 2018 qzhao@suse.com
- Add fonts-config-fix-misspelling.patch: fix misspelling in
  configuration file(boo#1111791).
* Mon Apr 30 2018 i@marguerite.su
- new upstream: https://github.com/openSUSE/fonts-config
  development will continue there.
- drop patch: fontconfig-infinality-generate-tt-groups.patch
  * infinality project is dead, we use a static result in upstream
    instead of generating it every time.
- update 20180430
  * support color emoji
  * modern fonts for symbol
  * add configurations for Noto Sans/Serif CJK
* Mon Mar 12 2018 stefan.bruens@rwth-aachen.de
- Do not create fonts.{dir,scale} in encodings directory
  (boo#1106850).
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Sep 21 2016 ftake@geeko.jp
- version 20160921
  * add 59-family-prefer-lang-specific.conf to specify prefered
    family for each language
  * fix Noto Sans CJK is used for serif alias (boo#998301)
  * assign monospace to default of Oxygen Mono
* Wed Sep 14 2016 pgajdos@suse.com
- version 20160914:
  * comma and the rest of family string is ignored while translating
    preference lists from sysconfig to fontconfig snippets
    [bsc#998300]
* Mon Nov  9 2015 pgajdos@suse.com
- Roboto prefered for sans and serif and Source Sans Pro for
  monospace [bsc#951898]
* Fri Aug 21 2015 qzhao@suse.com
- change fontconfig.SuSE.properties.template to fontconfig.SUSE.properties.template.
  * To full fit FATE#316521 Get rid of files using the old SUSE spelling.(bnc#942314)
* Fri Aug 14 2015 schwab@linux-m68k.org
- fonts-config: fix use of $ENV vars
* Fri Apr 24 2015 pgajdos@suse.com
- updated to 20150424:
  * introduce --remove-user-setting option
* Thu Apr 23 2015 pgajdos@suse.com
- updated to 20150423:
  * hide local system family preference list when user's one is
    in action
* Tue Apr 21 2015 pgajdos@suse.com
- updated to 20150421:
  * use mkpath instead of make_path [bnc#927968]
  * behave better when
    /usr/share/fontconfig/conf.avail/30-metric-aliases.conf
    not found
* Fri Apr 17 2015 pgajdos@suse.com
- updated to 20150417:
  * added --user option
* Mon Jan 12 2015 pgajdos@suse.com
- added Command: metadata to relevant sysconfig variables
  [bnc#912279]
* Sun Dec  7 2014 pgajdos@suse.com
- updated to 20141207
  added --info option (will be required by yast fonts)
* Mon Sep 22 2014 pgajdos@suse.com
- fix version in fonts-config script
* Mon Jul 28 2014 pgajdos@suse.com
- fixed typos in comments and debug outputs (hinstyle -> hintstyle)
* Wed Jun 11 2014 pgajdos@suse.com
- 10-rendering-options.conf and 58-family-prefer-local.conf are
  generated in every fonts-config call and as such should not
  be under /usr/share/fonts-config/conf.avail but under
  /etc/fonts/conf.d/ [bnc#882029]
* Wed Jun  4 2014 pgajdos@suse.com
- updated to 20140604:
  * remove duplicate family from PREFER_SERIF_FAMILIES in CFF
    example
  * add Source Serif Pro to PREFER_SERIF_FAMILIES in CFF example
  * introduce FORCE_FAMILY_PREFERENCE_LISTS sysconfig variable
* Thu May 22 2014 pgajdos@suse.com
- fallback to DejaVu Sans, Liberation Sans FPL order when
  no force_bw defined [bnc#878292c#12]
* Thu May 15 2014 pgajdos@suse.com
- fix comment for SEARCH_METRIC_COMPATIBLE
* Wed May 14 2014 tiwai@suse.de
- Don't force antialias for bitmap fonts for avoiding the render
  errors with Qt5 (bnc#866705)
* Fri Mar 21 2014 pgajdos@suse.com
- updated to 20140331:
  * allow ampersand in string sysconfig variable
  * xml-escape ampersand from <alias> family names
  * added bitmap font example for PREFER_*_FAMILIES
* Thu Mar 20 2014 pgajdos@suse.com
- fix default values and use list of possibilities in sysconfig
  file [bnc#869398] (internal)
* Fri Feb 28 2014 pgajdos@suse.com
- fix version in fonts-config script
* Wed Feb 26 2014 pgajdos@suse.com
- updated to 20140226:
  * FORCE_{SANS,SERIF,MONO}_PREFERENCE replaced by
    SEARCH_METRIC_COMPATIBLE
* Tue Feb 25 2014 pgajdos@suse.com
- updated to 20140225:
  * introduced FORCE_{SANS,SERIF,MONO}_PREFERENCE
* Mon Feb 24 2014 pgajdos@suse.com
- updated to 20140224:
  * add example of family preference: CFF fonts
* Fri Feb 21 2014 pgajdos@suse.com
- updated to 20140222:
  * don't use autohinter for CFF files
  * hinstlight for CFF files
* Fri Feb 21 2014 pgajdos@suse.com
- updated to 20140221
  * added 31-metric-aliases-bw.conf
* Thu Feb 13 2014 pgajdos@suse.com
- updated to 20140219
- revorked package, fontconfig configuration based on infinality
  one
- added patches:
  * fontconfig-infinality-main.patch (remove parts of original
    52-infinality.conf)
* Thu Jan 30 2014 pgajdos@suse.com
- fonts-config 20131102 [bnc#860097]:
  * do not check for font module used -> fixes TTCap entries
    generation
  * drop generating ghostscript fontmap
  * drop generating ooo xcu file
  * --quiet means quiet now
* Tue Oct  1 2013 pgajdos@suse.com
- workaround to [bnc#840416] as described in comment 20
* Mon Sep 17 2012 coolo@suse.com
- the script requires checkproc and killproc, otherwise it will start
  a xfs in buildroot (oops)
* Fri Sep 14 2012 pgajdos@suse.com
- cooperate with fontconfig 2.10.0 (removed /etc/fonts/conf.avail)
* Tue Aug 28 2012 pgajdos@suse.com
- remove SuSEconfig.fonts (openFATE#313536)
* Wed Aug  8 2012 pgajdos@suse.com
- call spec-cleaner
* Mon Aug  6 2012 pgajdos@suse.com
- prepare spec file for dropping SuSEconfig.fonts (openFATE#313536)
* Thu Jul 26 2012 pgajdos@suse.com
- add Requires(pre):  %%suseconfig_fonts_prereq [bnc#772644]
* Wed Jul 25 2012 tiwai@suse.de
- Fill some contents in the initial suse-bitmap.conf and
  suse-hinting-bc.conf (bnc#772664)
* Wed Jun 13 2012 tiwai@suse.de
- Add the support for IPAex fonts
* Tue Jun 12 2012 tiwai@suse.de
- Move hinting and bitmap config files to own config files
  instead of changing the main suse-*.conf (bnc#766319)
- Enable hinting_setup() again
* Mon Mar 26 2012 pgajdos@suse.com
- in generate_java_font_setup() was wrongly picked last installed
  font from @sans_latin1_priority, instead of first
* Fri Mar 23 2012 pgajdos@suse.com
- turn off hinting_setup() and font_dirs_setup()
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Dec  5 2011 pgajdos@suse.com
- generates also fonts for latin1 [bnc#732447]
- dropped java 1.4 support
* Mon Nov  7 2011 coolo@suse.com
- require perl(English), which is not part of perl-base
* Wed Oct 12 2011 ftake@geeko.jp
- changed Japanese fonts setting for Java
  * IPA Gothic for monospaced
  * Propotional IPA fonts for others
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Apr 26 2010 pgajdos@suse.cz
- fixed java's fontconfig.SuSE.properties location [bnc#591706]
* Wed Jan 28 2009 mfabian@suse.de
- apply patch by Egbert Eich to make handling of verbosity levels
  consistent.
* Tue Jun  3 2008 mfabian@suse.de
- bnc#396611: prefer "AR PL ShanHeiSun Uni" (uming.ttf) over
  FZMingTiB (/usr/share/fonts/truetype/FZMingTiB.ttf) for
  traditional Chinese in Java 1.5 because the former has embedded
  bitmaps and the latter has not.
* Mon Jan 21 2008 mfabian@suse.de
- fix recursive call of opendir() and closedir() to work with
  Perl 5.10.
* Tue Dec 18 2007 mfabian@suse.de
- add "Lucida Sans Typewriter", "Lucida Sans", and "Lucida Bright"
  to the list of fonts which should always use the byte code
  interpreter if anti-aliasing is off. Suggested by
  Bernhard Walle <bwalle@suse.de>.
* Wed Oct 10 2007 mfabian@suse.de
- acroread directory moved again because of the update to 8.1.1.
* Tue Sep 25 2007 mfabian@suse.de
- Bugzilla #327035: Skip symlinks when searching for font file
  names when generating the Java font setup.
* Thu Sep  6 2007 mfabian@suse.de
- Bugzilla #299432: add ‘Prereq: %%fillup_prereq’.
* Fri Mar 23 2007 mfabian@suse.de
- Bugzilla #118131 comment #93: set the autohinter default
  matching on "font" instead of on "pattern".
  If an autohint value is set in pattern, OpenOffice 2.1 will use
  that even if there are fontconfig rules matching on "font" which
  should override it again). This doesn't cause any problems for
  Cairo/Gnome (see bug #104365) because Cairo/Gnome don't try to
  change the autohint value anyway.
* Tue Jan 30 2007 mfabian@suse.de
- Bugzilla #239692: acroread moved to /usr/lib, add a new
  glob pattern to the font directory list.
* Wed Nov 22 2006 mfabian@suse.de
- Bugzilla #222675: disable autohinter for PostScript fonts.
* Wed Nov 15 2006 mfabian@suse.de
- Bugzilla #215602:  don't use the embedded bitmaps in the IPA
  fonts because they are only available in 12, 14, and 16 pixels.
- Bugzilla #215602: Don't use the autohinter for fonts where it
  it distorts the metrics so badly that even the digits which
  should be monospaced are not monospaced at all anymore.
- Don't use the autohinter for good quality TrueType fonts.
* Wed Oct 25 2006 mfabian@suse.de
- Fate #300950: after the regular setup is done, source all scripts
  in /usr/lib/fonts-config/conf.d which might do additional setup.
* Thu Sep 28 2006 mfabian@suse.de
- the OpenOffice font directory on x86_64 is
  /usr/lib64/ooo-2.0/share/fonts/truetype/.
* Wed Sep 13 2006 mfabian@suse.de
- some fonts have more than one space in the family name, replace
  them all with '_' where necessary in the Java setup.
* Tue Sep 12 2006 mfabian@suse.de
- improve Java 1.5 font setup for Chinese and Korean.
* Thu Aug 17 2006 mfabian@suse.de
- fix font paths in Java font setup for X11R7.
* Wed Aug 16 2006 mfabian@suse.de
- use "Recommends: ft2demos" only for SuSE Linux >= 10.1.
* Thu Aug 10 2006 mfabian@suse.de
- Bugzilla #195835: print a warning to stdout when the creation
  of a Fontmap for Ghostscript has been requested but the 'ftdump'
  binary is not available. Add "Recommends: ft2demos" to the .spec
  file because the 'ft2demos' package contains 'ftdump'. Mention
  'ftdump' in the comment above GENERATE_GHOSTSCRIPT_FONTMAPS
  in /etc/sysconfig/fonts-config. Mention ftdump in the manual page
  as well.
* Mon Jul  3 2006 mfabian@suse.de
- Add path names for X11R7
  (patch by Stefan Dirsch <sndirsch@suse.de>).
* Fri Apr 28 2006 mfabian@suse.de
- Bugzilla #104365: match on "pattern" instead on "font" to edit
  the default hinting settings to make it easier to override
  the defaults with applications using FcPatternDel() and
  FcPatternAdd...().
* Wed Apr 19 2006 schwab@suse.de
- Use /usr/bin/fc-cache-x86 when it exists.
* Tue Apr 11 2006 mfabian@suse.de
- Bugzilla #162978: also call /usr/bin/fc-cache64 if it exists
  (for ppc64).
- never use '--force' when calling /usr/bin/fc-cache32 and
  /usr/bin/fc-cache64.
* Mon Apr  3 2006 mfabian@suse.de
- Bugzilla #157441 comment #30 ff: make hintstyle=hintfull the
  default.
- Bugzilla #160226: call /usr/bin/fc-cache32 if it exists.
* Fri Feb 10 2006 mfabian@suse.de
- Bugzilla #148359: do not touch /usr/X11R6/lib/X11/fonts in
  SuSEconfig.fonts to find out whether this is on a readonly
  file system. Even if it is on a readonly file system, caches
  for fontconfig can still be generated in /var/cache/fontconfig.
  And it might still be possible to generate fonts.dir/fonts.scale
  files in other directories, i.e. /usr/sbin/fonts-config should
  be started always.
* Tue Feb  7 2006 mfabian@suse.de
- Bugzilla #148361: generate /etc/fonts/suse-font-dirs.conf from
  a template containing glob patterns to a full list of all
  font directories to avoid that fontconfig calls stat () on all
  files in all sub-directories.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 mfabian@suse.de
- Bugzilla #105626: Takashi IWAI <tiwai@suse.de> made patches for
  freetype2 to improve the autohinting (mainly for CJK fonts).
  Now we don't need to switch off the autohinter for CJK fonts
  any more.
* Wed Jan  4 2006 mfabian@suse.de
- update to 20060104:
- make it work better together with fontconfig 2.3.93.20060103
  and require fontconfig >= 2.3.93.20060103
- remove old cruft which was used for Xft1 and older versions
  of fontconfig
- write autogenerated files in /etc/fonts only if their contents
  have changed, touching these files causes fontconfig to believe
  that the caches are out of date.
- fix glob pattern for font.properties.ja (for java 1.4.2).
* Wed Jan  4 2006 mfabian@suse.de
- Bugzilla #131714: always use byte code interpreter for some
  composite CJK fonts which cannot be rendered correctly with the
  autohinter. Currently the only fonts I know which need this
  are the traditional Chinese fonts MingLiU and PMingLiU.
* Thu Oct 27 2005 mfabian@suse.de
- Bugzilla #130350: add "Andale Sans", "Andy MT", "Bell MT", and
  "Monotype Sorts" to the list of fonts which are rendered with
  the byte code interpreter and without anti-aliasing up to the
  pixellimit specified in /etc/sysconfig/fonts-config.
  These fonts appear to have good byte code as well, the results
  when rendered this way look OK.
* Thu Oct 27 2005 mfabian@suse.de
- revert last change because I downgraded to fontconfig
  2.3.2.20050721 (the version from SUSE 10.0) in STABLE.
  This fontconfig version is solid and works reliable. The
  fontconfig 2.4 branch will be checked into BETA and come
  back to STABLE as soon as the crash problems are solved.
* Wed Oct 26 2005 mfabian@suse.de
- Bugzilla #128080: add option "--force" to the call of
  fonts-config in SuSEconfig.fonts.
  This is only a temporary workaround until the real problem
  in fontconfig is fixed. With this workaround, SuSEconfig.fonts
  needs a lot more time but at least it appears to work reliably.
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Thu Sep  8 2005 mfabian@suse.de
- Bugzilla #114949:
  + really add variable to enable the byte code
    interpreter to /etc/sysconfig/fonts-config. The last change
    contained only the code to use this variable if available but
    not the variable itself.
  + add variables in /etc/sysconfig/fonts-config
    to choose whether embedded bitmaps should be used and for
    which languages.
* Tue Sep  6 2005 mfabian@suse.de
- Bugzilla #114949: add a variable in /etc/sysconfig/fonts-config
  to choose whether black and white rendering using the byte code
  interpreter should be used and up to which pixel size.
* Tue Sep  6 2005 mfabian@suse.de
- Bugzilla #79259 again: I found a bug in the autogeneration of
  the Java font setup: sometimes "fc-list font file"  may return
  several results, for example if there are symlinks which point
  to the same font and also if one of the CID-keyed fonts
  created by the script /usr/sbin/acroread-cidfont-config happens
  to have the same family name. These CID-keyed fonts and the
  must be ignored, neither of them will work with Java.
* Mon Sep  5 2005 mfabian@suse.de
- Bugzilla #79259: add autogeneration of Java font configuration
  files.
* Fri Mar  4 2005 mfabian@suse.de
- add missing %%prep section to .spec file.
* Mon Dec  6 2004 mfabian@suse.de
- Bugzilla #48603: don't try to write OpenOffice font-setup if
  OpenOffice is not installed.
* Fri Oct  1 2004 mfabian@suse.de
- Bugzilla #46299: improve OpenOffice font setup for Japanese
  for better on screen display and printing.
* Tue Jul  6 2004 mfabian@suse.de
- make package "noarch".
- make fonts which have spaces in the filename usable with
  the X11 core font system by generating symbolic links.
- checkproc was still used without absolute path in one place.
* Wed May  5 2004 sndirsch@suse.de
- created package
